# Changelog

## 1.1.0
- Added release-ready packaging structure
- Added full `pyproject.toml`
- Added CLI entry point: `nest-ui`
- Added optional extras for voice, ops, and clipboard
- Added GitHub Actions workflows for tests and publishing
- Added release documentation and contributor guide
- Added example app and baseline tests
